Skip to contents

This function generates a Monte Carlo method sampling distribution of the standardized total effect centrality at a particular time interval \(\Delta t\) using the first-order stochastic differential equation model drift matrix \(\boldsymbol{\Phi}\) and process noise covariance matrix \(\boldsymbol{\Sigma}\).

Usage

MCTotalCentralStd(
  phi,
  sigma,
  vcov_theta,
  delta_t,
  R,
  test_phi = TRUE,
  sigma_diag = FALSE,
  ncores = NULL,
  seed = NULL,
  tol = 0.001
)

Arguments

phi

Numeric matrix. The drift matrix (\(\boldsymbol{\Phi}\)). phi should have row and column names pertaining to the variables in the system.

sigma

Numeric matrix. The process noise covariance matrix (\(\boldsymbol{\Sigma}\)).

vcov_theta

Numeric matrix. The sampling variance-covariance matrix of \(\mathrm{vec} \left( \boldsymbol{\Phi} \right)\) and \(\mathrm{vech} \left( \boldsymbol{\Sigma} \right)\)

delta_t

Numeric. Time interval (\(\Delta t\)).

R

Positive integer. Number of replications.

test_phi

Logical. If test_phi = TRUE, the function tests the stability of the generated drift matrix \(\boldsymbol{\Phi}\). If the test returns FALSE, the function generates a new drift matrix \(\boldsymbol{\Phi}\) and runs the test recursively until the test returns TRUE.

sigma_diag

Logical. If sigma_diag = TRUE, treat \(\boldsymbol{\Sigma}\) as a diagonal matrix.

ncores

Positive integer. Number of cores to use. If ncores = NULL, use a single core. Consider using multiple cores when number of replications R is a large value.

seed

Random seed.

tol

Numeric. Smallest possible time interval to allow.

Value

Returns an object of class ctmedmc which is a list with the following elements:

call

Function call.

args

Function arguments.

fun

Function used ("MCTotalCentralStd").

output

A list of length length(delta_t).

Each element in the output list has the following elements:

est

A vector of standardized total effect centrality.

thetahatstar

A matrix of Monte Carlo standardized total effect centrality.

Details

See TotalCentralStd() for more details.

Monte Carlo Method

Let \(\boldsymbol{\theta}\) be a vector that combines \(\mathrm{vec} \left( \boldsymbol{\Phi} \right)\), that is, the elements of the \(\boldsymbol{\Phi}\) matrix in vector form sorted column-wise and \(\mathrm{vech} \left( \boldsymbol{\Sigma} \right)\), that is, the unique elements of the \(\boldsymbol{\Sigma}\) matrix in vector form sorted column-wise. Let \(\hat{\boldsymbol{\theta}}\) be a vector that combines \(\mathrm{vec} \left( \hat{\boldsymbol{\Phi}} \right)\) and \(\mathrm{vech} \left( \hat{\boldsymbol{\Sigma}} \right)\). Based on the asymptotic properties of maximum likelihood estimators, we can assume that estimators are normally distributed around the population parameters. $$ \hat{\boldsymbol{\theta}} \sim \mathcal{N} \left( \boldsymbol{\theta}, \mathbb{V} \left( \hat{\boldsymbol{\theta}} \right) \right) $$ Using this distributional assumption, a sampling distribution of \(\hat{\boldsymbol{\theta}}\) which we refer to as \(\hat{\boldsymbol{\theta}}^{\ast}\) can be generated by replacing the population parameters with sample estimates, that is, $$ \hat{\boldsymbol{\theta}}^{\ast} \sim \mathcal{N} \left( \hat{\boldsymbol{\theta}}, \hat{\mathbb{V}} \left( \hat{\boldsymbol{\theta}} \right) \right) . $$ Let \(\mathbf{g} \left( \hat{\boldsymbol{\theta}} \right)\) be a parameter that is a function of the estimated parameters. A sampling distribution of \(\mathbf{g} \left( \hat{\boldsymbol{\theta}} \right)\) , which we refer to as \(\mathbf{g} \left( \hat{\boldsymbol{\theta}}^{\ast} \right)\) , can be generated by using the simulated estimates to calculate \(\mathbf{g}\). The standard deviations of the simulated estimates are the standard errors. Percentiles corresponding to \(100 \left( 1 - \alpha \right) \%\) are the confidence intervals.

References

Bollen, K. A. (1987). Total, direct, and indirect effects in structural equation models. Sociological Methodology, 17, 37. doi:10.2307/271028

Deboeck, P. R., & Preacher, K. J. (2015). No need to be discrete: A method for continuous time mediation analysis. Structural Equation Modeling: A Multidisciplinary Journal, 23 (1), 61-75. doi:10.1080/10705511.2014.973960

Pesigan, I. J. A., Russell, M. A., & Chow, S.-M. (2025). Inferences and effect sizes for direct, indirect, and total effects in continuous-time mediation models. Psychological Methods. doi:10.1037/met0000779

Ryan, O., & Hamaker, E. L. (2021). Time to intervene: A continuous-time approach to network analysis and centrality. Psychometrika, 87 (1), 214-252. doi:10.1007/s11336-021-09767-0

Author

Ivan Jacob Agaloos Pesigan

Examples

phi <- matrix(
  data = c(
    -0.357, 0.771, -0.450,
    0.0, -0.511, 0.729,
    0, 0, -0.693
  ),
  nrow = 3
)
colnames(phi) <- rownames(phi) <- c("x", "m", "y")
sigma <- matrix(
  data = c(
    0.24455556, 0.02201587, -0.05004762,
    0.02201587, 0.07067800, 0.01539456,
    -0.05004762, 0.01539456, 0.07553061
  ),
  nrow = 3
)
vcov_theta <- matrix(
  data = c(
    0.00843, 0.00040, -0.00151, -0.00600, -0.00033,
    0.00110, 0.00324, 0.00020, -0.00061, -0.00115,
    0.00011, 0.00015, 0.00001, -0.00002, -0.00001,
    0.00040, 0.00374, 0.00016, -0.00022, -0.00273,
    -0.00016, 0.00009, 0.00150, 0.00012, -0.00010,
    -0.00026, 0.00002, 0.00012, 0.00004, -0.00001,
    -0.00151, 0.00016, 0.00389, 0.00103, -0.00007,
    -0.00283, -0.00050, 0.00000, 0.00156, 0.00021,
    -0.00005, -0.00031, 0.00001, 0.00007, 0.00006,
    -0.00600, -0.00022, 0.00103, 0.00644, 0.00031,
    -0.00119, -0.00374, -0.00021, 0.00070, 0.00064,
    -0.00015, -0.00005, 0.00000, 0.00003, -0.00001,
    -0.00033, -0.00273, -0.00007, 0.00031, 0.00287,
    0.00013, -0.00014, -0.00170, -0.00012, 0.00006,
    0.00014, -0.00001, -0.00015, 0.00000, 0.00001,
    0.00110, -0.00016, -0.00283, -0.00119, 0.00013,
    0.00297, 0.00063, -0.00004, -0.00177, -0.00013,
    0.00005, 0.00017, -0.00002, -0.00008, 0.00001,
    0.00324, 0.00009, -0.00050, -0.00374, -0.00014,
    0.00063, 0.00495, 0.00024, -0.00093, -0.00020,
    0.00006, -0.00010, 0.00000, -0.00001, 0.00004,
    0.00020, 0.00150, 0.00000, -0.00021, -0.00170,
    -0.00004, 0.00024, 0.00214, 0.00012, -0.00002,
    -0.00004, 0.00000, 0.00006, -0.00005, -0.00001,
    -0.00061, 0.00012, 0.00156, 0.00070, -0.00012,
    -0.00177, -0.00093, 0.00012, 0.00223, 0.00004,
    -0.00002, -0.00003, 0.00001, 0.00003, -0.00013,
    -0.00115, -0.00010, 0.00021, 0.00064, 0.00006,
    -0.00013, -0.00020, -0.00002, 0.00004, 0.00057,
    0.00001, -0.00009, 0.00000, 0.00000, 0.00001,
    0.00011, -0.00026, -0.00005, -0.00015, 0.00014,
    0.00005, 0.00006, -0.00004, -0.00002, 0.00001,
    0.00012, 0.00001, 0.00000, -0.00002, 0.00000,
    0.00015, 0.00002, -0.00031, -0.00005, -0.00001,
    0.00017, -0.00010, 0.00000, -0.00003, -0.00009,
    0.00001, 0.00014, 0.00000, 0.00000, -0.00005,
    0.00001, 0.00012, 0.00001, 0.00000, -0.00015,
    -0.00002, 0.00000, 0.00006, 0.00001, 0.00000,
    0.00000, 0.00000, 0.00010, 0.00001, 0.00000,
    -0.00002, 0.00004, 0.00007, 0.00003, 0.00000,
    -0.00008, -0.00001, -0.00005, 0.00003, 0.00000,
    -0.00002, 0.00000, 0.00001, 0.00005, 0.00001,
    -0.00001, -0.00001, 0.00006, -0.00001, 0.00001,
    0.00001, 0.00004, -0.00001, -0.00013, 0.00001,
    0.00000, -0.00005, 0.00000, 0.00001, 0.00012
  ),
  nrow = 15
)

# Specific time interval ----------------------------------------------------
MCTotalCentralStd(
  phi = phi,
  sigma = sigma,
  vcov_theta = vcov_theta,
  delta_t = 1,
  R = 100L # use a large value for R in actual research
)
#> Call:
#> MCTotalCentralStd(phi = phi, sigma = sigma, vcov_theta = vcov_theta, 
#>     delta_t = 1, R = 100L)
#> 
#> Total Effect Centrality
#>   variable interval    est     se   R    2.5%  97.5%
#> 1        x        1 0.2819 0.0449 100  0.1938 0.3598
#> 2        m        1 0.5494 0.0587 100  0.4263 0.6647
#> 3        y        1 0.0000 0.0516 100 -0.0966 0.0861

# Range of time intervals ---------------------------------------------------
mc <- MCTotalCentralStd(
  phi = phi,
  sigma = sigma,
  vcov_theta = vcov_theta,
  delta_t = 1:5,
  R = 100L # use a large value for R in actual research
)
plot(mc)




# Methods -------------------------------------------------------------------
# MCTotalCentralStd has a number of methods including
# print, summary, confint, and plot
print(mc)
#> Call:
#> MCTotalCentralStd(phi = phi, sigma = sigma, vcov_theta = vcov_theta, 
#>     delta_t = 1:5, R = 100L)
#> 
#> Total Effect Centrality
#>    variable interval    est     se   R    2.5%  97.5%
#> 1         x        1 0.2819 0.0481 100  0.1961 0.3704
#> 2         m        1 0.5494 0.0600 100  0.4254 0.6502
#> 3         y        1 0.0000 0.0572 100 -0.0975 0.1114
#> 4         x        2 0.5907 0.0610 100  0.4732 0.7091
#> 5         m        2 0.6044 0.0719 100  0.4591 0.7439
#> 6         y        2 0.0000 0.0823 100 -0.1416 0.1570
#> 7         x        3 0.7616 0.0675 100  0.6411 0.9133
#> 8         m        3 0.4999 0.0782 100  0.3532 0.6454
#> 9         y        3 0.0000 0.0877 100 -0.1543 0.1663
#> 10        x        4 0.7979 0.0742 100  0.6847 0.9638
#> 11        m        4 0.3686 0.0825 100  0.2184 0.5366
#> 12        y        4 0.0000 0.0823 100 -0.1445 0.1579
#> 13        x        5 0.7453 0.0804 100  0.6223 0.8965
#> 14        m        5 0.2555 0.0841 100  0.1044 0.4387
#> 15        y        5 0.0000 0.0719 100 -0.1238 0.1428
summary(mc)
#> Call:
#> MCTotalCentralStd(phi = phi, sigma = sigma, vcov_theta = vcov_theta, 
#>     delta_t = 1:5, R = 100L)
#> 
#> Total Effect Centrality
#>    variable interval    est     se   R    2.5%  97.5%
#> 1         x        1 0.2819 0.0481 100  0.1961 0.3704
#> 2         m        1 0.5494 0.0600 100  0.4254 0.6502
#> 3         y        1 0.0000 0.0572 100 -0.0975 0.1114
#> 4         x        2 0.5907 0.0610 100  0.4732 0.7091
#> 5         m        2 0.6044 0.0719 100  0.4591 0.7439
#> 6         y        2 0.0000 0.0823 100 -0.1416 0.1570
#> 7         x        3 0.7616 0.0675 100  0.6411 0.9133
#> 8         m        3 0.4999 0.0782 100  0.3532 0.6454
#> 9         y        3 0.0000 0.0877 100 -0.1543 0.1663
#> 10        x        4 0.7979 0.0742 100  0.6847 0.9638
#> 11        m        4 0.3686 0.0825 100  0.2184 0.5366
#> 12        y        4 0.0000 0.0823 100 -0.1445 0.1579
#> 13        x        5 0.7453 0.0804 100  0.6223 0.8965
#> 14        m        5 0.2555 0.0841 100  0.1044 0.4387
#> 15        y        5 0.0000 0.0719 100 -0.1238 0.1428
confint(mc, level = 0.95)
#>    variable interval      2.5 %    97.5 %
#> 1         x        1  0.1960577 0.3704132
#> 2         m        1  0.4254124 0.6502248
#> 3         y        1 -0.0974724 0.1113832
#> 4         x        2  0.4731885 0.7091336
#> 5         m        2  0.4591043 0.7439077
#> 6         y        2 -0.1415604 0.1569608
#> 7         x        3  0.6411218 0.9132845
#> 8         m        3  0.3532089 0.6453852
#> 9         y        3 -0.1543062 0.1662588
#> 10        x        4  0.6847148 0.9638378
#> 11        m        4  0.2184464 0.5366106
#> 12        y        4 -0.1444779 0.1579205
#> 13        x        5  0.6223279 0.8964562
#> 14        m        5  0.1043794 0.4387486
#> 15        y        5 -0.1237940 0.1427508
plot(mc)