Learn R Programming

cTMed (version 1.0.10)

DirectCentralStd: Standardized Direct Effect Centrality

Description

Standardized Direct Effect Centrality

Usage

DirectCentralStd(phi, sigma, delta_t, tol = 0.001)

Value

Returns an object of class ctmedmed which is a list with the following elements:

call

Function call.

args

Function arguments.

fun

Function used ("DirectCentralStd").

output

A matrix of standardized direct effect centrality.

Arguments

phi

Numeric matrix. The drift matrix (\(\boldsymbol{\Phi}\)). phi should have row and column names pertaining to the variables in the system.

sigma

Numeric matrix. The process noise covariance matrix (\(\boldsymbol{\Sigma}\)).

delta_t

Vector of positive numbers. Time interval (\(\Delta t\)).

tol

Numeric. Smallest possible time interval to allow.

Author

Ivan Jacob Agaloos Pesigan

Details

Standardized direct effect centrality is the sum of all possible standardized direct effects between different pairs of variables in which a specific variable serves as the only mediator.

See Also

Other Continuous-Time Mediation Functions: BootBeta(), BootBetaStd(), BootDirectCentral(), BootDirectCentralStd(), BootIndirectCentral(), BootIndirectCentralStd(), BootMed(), BootMedStd(), BootTotalCentral(), BootTotalCentralStd(), DeltaBeta(), DeltaBetaStd(), DeltaDirectCentral(), DeltaDirectCentralStd(), DeltaIndirectCentral(), DeltaMed(), DeltaMedStd(), DeltaTotalCentral(), DeltaTotalCentralStd(), Direct(), DirectCentral(), DirectStd(), Indirect(), IndirectCentral(), IndirectCentralStd(), IndirectStd(), MCBeta(), MCBetaStd(), MCDirectCentral(), MCDirectCentralStd(), MCIndirectCentral(), MCIndirectCentralStd(), MCMed(), MCMedStd(), MCPhi(), MCPhiSigma(), MCTotalCentral(), MCTotalCentralStd(), Med(), MedStd(), PosteriorBeta(), PosteriorBetaStd(), PosteriorDirectCentral(), PosteriorDirectCentralStd(), PosteriorIndirectCentral(), PosteriorIndirectCentralStd(), PosteriorMed(), PosteriorMedStd(), PosteriorTotalCentral(), PosteriorTotalCentralStd(), Total(), TotalCentral(), TotalCentralStd(), TotalStd(), Trajectory()

Examples

Run this code
phi <- matrix(
  data = c(
    -0.357, 0.771, -0.450,
    0.0, -0.511, 0.729,
    0, 0, -0.693
  ),
  nrow = 3
)
colnames(phi) <- rownames(phi) <- c("x", "m", "y")
sigma <- matrix(
  data = c(
    0.24455556, 0.02201587, -0.05004762,
    0.02201587, 0.07067800, 0.01539456,
    -0.05004762, 0.01539456, 0.07553061
  ),
  nrow = 3
)

# Specific time interval ----------------------------------------------------
DirectCentralStd(
  phi = phi,
  sigma = sigma,
  delta_t = 1
)

# Range of time intervals ---------------------------------------------------
direct_central_std <- DirectCentralStd(
  phi = phi,
  sigma = sigma,
  delta_t = 1:30
)
plot(direct_central_std)

# Methods -------------------------------------------------------------------
# DirectCentralStd has a number of methods including
# print, summary, and plot
direct_central_std <- DirectCentralStd(
  phi = phi,
  sigma = sigma,
  delta_t = 1:5
)
print(direct_central_std)
summary(direct_central_std)
plot(direct_central_std)

Run the code above in your browser using DataLab